# get_inertia

This package just includes a simple tool to get the inertia matrix of a STL model.

This might be particularly useful when scripting.

The tool can be called as:
```
get_inertia my_model.stl
```
